.. PIDSIM documentation master file, created by
   sphinx-quickstart on Fri Oct 29 16:46:33 2010.

.. include:: ../README.rst


API documentation
~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 2

   base
   models


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

